<?php

/* Plugin name: Wordpress Questions Widgets
 * Description: Adds "Your recent posts" and "Your recent comments" widgets.
 * Author: Jurre Hanema
 */


add_action('widgets_init', 'wpq_register_widgets');


function wpq_register_widgets()
{
	register_widget('WPQ_Widget_Your_Recent_Comments');
	register_widget('WPQ_Widget_Your_Recent_Posts');
}


class WPQ_Widget_Your_Recent_Posts extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'wpq_widget_your_recent_entries', 'description' => __( "The most recent posts made by the current user on your site") );
		parent::__construct('wpq-your-recent-posts', __('Your Recent Posts'), $widget_ops);
		$this->alt_option_name = 'wpq_widget_your_recent_entries';

		//add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		//add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		//add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		//$cache = wp_cache_get('widget_recent_posts', 'widget');

		//if ( !is_array($cache) )
		//	$cache = array();

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		//if ( isset( $cache[ $args['widget_id'] ] ) ) {
		//	echo $cache[ $args['widget_id'] ];
		//	return;
		//}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Posts') : $instance['title'], $instance, $this->id_base);
		if ( empty( $instance['number'] ) || ! $number = absint( $instance['number'] ) )
 			$number = 10;

		$current_user = wp_get_current_user();
		
		if($current_user->ID)
		{		
			$r = new WP_Query(array('posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true, 'author' => $current_user->ID));
			if ($r->have_posts()) :
			?>
			<?php echo $before_widget; ?>
			<?php if ( $title ) echo $before_title . $title . $after_title; ?>
			<ul>
			<?php  while ($r->have_posts()) : $r->the_post(); ?>
			<li><a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a></li>
			<?php endwhile; ?>
			</ul>
			<?php echo $after_widget; ?>
			<?php
			// Reset the global $the_post as this query will have stomped on it
			wp_reset_postdata();

			endif;
		}

		//$cache[$args['widget_id']] = ob_get_flush();
		//wp_cache_set('wpq_widget_your_recent_posts', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		//$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['wpq_widget_your_recent_entries']) )
			delete_option('wpq_widget_your_recent_entries');

		return $instance;
	}

	/*function flush_widget_cache() {
		wp_cache_delete('wpq_widget_your_recent_posts', 'widget');
	}*/

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$number = isset($instance['number']) ? absint($instance['number']) : 5;
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts to show:'); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
	}
}


class WPQ_Widget_Your_Recent_Comments extends WP_Widget {

	function __construct() {
		$widget_ops = array('classname' => 'wpq_widget_your_recent_comments', 'description' => __( 'The most recent comments by the current user' ) );
		parent::__construct('wpq-your-recent-comments', __('Your Recent Comments'), $widget_ops);
		$this->alt_option_name = 'widget_recent_comments';

		if ( is_active_widget(false, false, $this->id_base) )
			add_action( 'wp_head', array(&$this, 'recent_comments_style') );

		//add_action( 'comment_post', array(&$this, 'flush_widget_cache') );
		//add_action( 'transition_comment_status', array(&$this, 'flush_widget_cache') );
	}

	function recent_comments_style() {
		if ( ! current_theme_supports( 'widgets' ) // Temp hack #14876
			|| ! apply_filters( 'show_recent_comments_widget_style', true, $this->id_base ) )
			return;
		?>
	<style type="text/css">.recentcomments a{display:inline !important;padding:0 !important;margin:0 !important;}</style>
<?php
	}

	/*function flush_widget_cache() {
		wp_cache_delete('wpq_widget_your_recent_comments', 'widget');
	}*/

	function widget( $args, $instance ) {
		global $comments, $comment;

		/*$cache = wp_cache_get('wpq_widget_your_recent_comments', 'widget');

		if ( ! is_array( $cache ) )
			$cache = array();*/

		if ( ! isset( $args['widget_id'] ) )
			$args['widget_id'] = $this->id;

		/*if ( isset( $cache[ $args['widget_id'] ] ) ) {
			echo $cache[ $args['widget_id'] ];
			return;
		}*/

 		extract($args, EXTR_SKIP);
 		$output = '';
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? __( 'Your Recent Comments' ) : $instance['title'], $instance, $this->id_base );

		if ( empty( $instance['number'] ) || ! $number = absint( $instance['number'] ) )
 			$number = 5;

		$current_user = wp_get_current_user();
		
		if($current_user->ID)
		{
			$comments = get_comments( array( 'number' => $number, 'status' => 'approve', 'post_status' => 'publish', 'user_id' => $current_user->ID ) );
			$output .= $before_widget;
			if ( $title )
				$output .= $before_title . $title . $after_title;

			$output .= '<ul id="your-recentcomments">';
			if ( $comments ) {
				foreach ( (array) $comments as $comment) {
					$output .=  '<li class="recentcomments">' . /* translators: comments widget: 1: comment author, 2: post link */ sprintf(_x('%1$s on %2$s', 'widgets'), get_comment_author_link(), '<a href="' . esc_url( get_comment_link($comment->comment_ID) ) . '">' . get_the_title($comment->comment_post_ID) . '</a>') . '</li>';
				}
			}
			$output .= '</ul>';
			$output .= $after_widget;

			echo $output;
		}
		
		//$cache[$args['widget_id']] = $output;
		//wp_cache_set('wpq_widget_your_recent_comments', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = absint( $new_instance['number'] );
		//$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['wpq_widget_your_recent_comments']) )
			delete_option('wpq_widget_your_recent_comments');

		return $instance;
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		$number = isset($instance['number']) ? absint($instance['number']) : 5;
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of comments to show:'); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
	}
}

?>